@@ -1,6 +1,7 @@
 import json
 import os
 from percy.common import log
+from percy.lib.tile import Tile
 from percy.providers.generic_provider import GenericProvider
 
 
@@ -30,6 +31,29 @@ class AppAutomate(GenericProvider):
         session_hash = session_details.get("sessionHash")
         self.debug_url = "https://app-automate.browserstack.com/dashboard/v2/builds/" + build_hash + "/sessions/" + session_hash
 
+    def _get_tiles(self, **kwargs):
+        fullpage_ss = kwargs.get('fullpage', False)
+        if not fullpage_ss:
+            return super()._get_tiles(**kwargs)
+        screen_lengths = kwargs.get('screen_lengths', 4)
+        data = self.execute_percy_screenshot(
+            self.metadata.device_screen_size.get('height', 1),
+            screen_lengths,
+            self.metadata.scale_factor,
+        )
+        tiles = []
+        status_bar_height = self.metadata.status_bar_height
+        nav_bar_height = self.metadata.navigation_bar_height
+        for tile_data in json.loads(data.get('result')):
+            tiles.append(Tile(
+                status_bar_height,
+                nav_bar_height,
+                tile_data.get('header_height'),
+                tile_data.get('footer_height'),
+                sha=tile_data.get('sha').split("-")[0]
+            ))
+        return tiles
+
     def execute_percy_screenshot_begin(self, name):
         try:
             request_body = {
@@ -67,3 +91,24 @@ class AppAutomate(GenericProvider):
         except Exception as e:
             log('Error occurred during end call', on_debug=True)
             log(e, on_debug=True)
+
+    def execute_percy_screenshot(self, device_height, screen_lengths, scale_factor=1):
+        try:
+            request_body = {
+                'action': 'percyScreenshot',
+                'arguments': {
+                    'state': 'screenshot',
+                    'percyBuildId':  os.getenv('PERCY_BUILD_ID', ''),
+                    'screenshotType': 'fullpage',
+                    'scaleFactor': scale_factor,
+                    'options': { "numOfTiles": screen_lengths, "deviceHeight": device_height },
+                }
+            }
+            command = f'browserstack_executor: {json.dumps(request_body)}'
+            response = self.metadata.execute_script(command)
+            response = json.loads(response)
+            return response
+        except Exception as e:
+            log('Error occurred during screenshot call', on_debug=True)
+            log(e, on_debug=True)
+            raise e
